@@ -1,4 +1,4 @@
-"""
+'''
 # aws-apigateway-sagemakerendpoint module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -117,7 +117,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -141,9 +141,9 @@ class ApiGatewayToSageMakerEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-sagemakerendpoint.ApiGatewayToSageMakerEndpoint",
 ):
-    """
+    '''
     :summary: The ApiGatewayToSageMakerEndpoint class.
-    """
+    '''
 
     def __init__(
         self,
@@ -159,7 +159,7 @@ class ApiGatewayToSageMakerEndpoint(
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param endpoint_name: Name of the deployed SageMaker inference endpoint. Default: - None.
@@ -174,7 +174,7 @@ class ApiGatewayToSageMakerEndpoint(
         :access: public
         :since: 1.68.0
         :summary: Constructs a new instance of the ApiGatewayToSageMakerEndpoint class.
-        """
+        '''
         props = ApiGatewayToSageMakerEndpointProps(
             endpoint_name=endpoint_name,
             request_mapping_template=request_mapping_template,
@@ -236,7 +236,7 @@ class ApiGatewayToSageMakerEndpointProps:
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param endpoint_name: Name of the deployed SageMaker inference endpoint. Default: - None.
         :param request_mapping_template: Mapping template to convert GET requests received on the REST API to POST requests expected by the SageMaker endpoint. Default: - None.
         :param resource_path: Resource path for the GET method. The variable defined here can be referenced in ``requestMappingTemplate``. Default: - None.
@@ -247,7 +247,7 @@ class ApiGatewayToSageMakerEndpointProps:
         :param response_mapping_template: Optional mapping template to convert responses received from the SageMaker endpoint. Default: - None.
 
         :summary: The properties for the ApiGatewayToSageMakerEndpointProps class.
-        """
+        '''
         if isinstance(api_gateway_props, dict):
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
@@ -270,78 +270,78 @@ class ApiGatewayToSageMakerEndpointProps:
 
     @builtins.property
     def endpoint_name(self) -> builtins.str:
-        """Name of the deployed SageMaker inference endpoint.
+        '''Name of the deployed SageMaker inference endpoint.
 
         :default: - None.
-        """
+        '''
         result = self._values.get("endpoint_name")
         assert result is not None, "Required property 'endpoint_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def request_mapping_template(self) -> builtins.str:
-        """Mapping template to convert GET requests received on the REST API to POST requests expected by the SageMaker endpoint.
+        '''Mapping template to convert GET requests received on the REST API to POST requests expected by the SageMaker endpoint.
 
         :default: - None.
-        """
+        '''
         result = self._values.get("request_mapping_template")
         assert result is not None, "Required property 'request_mapping_template' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def resource_path(self) -> builtins.str:
-        """Resource path for the GET method.
+        '''Resource path for the GET method.
 
         The variable defined here can be referenced in ``requestMappingTemplate``.
 
         :default: - None.
-        """
+        '''
         result = self._values.get("resource_path")
         assert result is not None, "Required property 'resource_path' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def api_gateway_execution_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
-        """Optional IAM role that is used by API Gateway to invoke the SageMaker endpoint.
+        '''Optional IAM role that is used by API Gateway to invoke the SageMaker endpoint.
 
         :default: - An IAM role with sagemaker:InvokeEndpoint access to ``endpointName`` is created.
-        """
+        '''
         result = self._values.get("api_gateway_execution_role")
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], result)
 
     @builtins.property
     def api_gateway_props(self) -> typing.Optional[aws_cdk.aws_apigateway.RestApiProps]:
-        """Optional user-provided props to override the default props for the API Gateway.
+        '''Optional user-provided props to override the default props for the API Gateway.
 
         :default: - Default properties are used.
-        """
+        '''
         result = self._values.get("api_gateway_props")
         return typing.cast(typing.Optional[aws_cdk.aws_apigateway.RestApiProps], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
     @builtins.property
     def resource_name(self) -> typing.Optional[builtins.str]:
-        """Optional resource name where the GET method will be available.
+        '''Optional resource name where the GET method will be available.
 
         :default: - None.
-        """
+        '''
         result = self._values.get("resource_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def response_mapping_template(self) -> typing.Optional[builtins.str]:
-        """Optional mapping template to convert responses received from the SageMaker endpoint.
+        '''Optional mapping template to convert responses received from the SageMaker endpoint.
 
         :default: - None.
-        """
+        '''
         result = self._values.get("response_mapping_template")
         return typing.cast(typing.Optional[builtins.str], result)
 
